Managed task execution services.
This module contains task-oriented services that assign stable task IDs and
track execution status while delegating actual concurrency to
qubit-executor and qubit-thread-pool.
Structs
- Stop
Report - Summary returned by an immediate executor-service stop request.
- Task
Execution Service - Managed task execution service built on
ThreadPool. - Task
Execution Service Builder - Builder for
TaskExecutionService, used to configure the backingsuper::ThreadPoolbefore the service is created. - Task
Execution Stats - Count snapshot for a
TaskExecutionService. - Thread
Pool - OS thread pool implementing
ExecutorService. - Thread
Pool Builder - Builder for
ThreadPool. - Thread
Pool Stats - Point-in-time counters reported by
crate::ThreadPool.
Enums
- Executor
Service Builder Error - Error returned when an executor service cannot be built.
- Submission
Error - Error returned when an executor service refuses to accept a task.
- Task
Execution Service Error - Error returned when
TaskExecutionServicecannot accept a task. - Task
Status - Status of a task managed by
TaskExecutionService.
Type Aliases
- TaskId
- Identifier type used by
TaskExecutionService.